Class: Google::Api::UsageRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/usage.rb

Overview

Usage configuration rules for the service.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_unregistered_calls::Boolean

Returns Use this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key).

WARNING: By default, API methods do not allow unregistered calls, and each method call must be identified by a consumer project identity.

Returns:

  • (::Boolean)

    Use this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key).

    WARNING: By default, API methods do not allow unregistered calls, and each method call must be identified by a consumer project identity.



76
77
78
79
# File 'proto_docs/google/api/usage.rb', line 76

class UsageRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#selector::String

Returns Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs.

Refer to selector for syntax details.

Returns:

  • (::String)

    Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs.

    Refer to selector for syntax details.



76
77
78
79
# File 'proto_docs/google/api/usage.rb', line 76

class UsageRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip_service_control::Boolean

Returns If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available. This flag is used by Google Cloud Endpoints to bypass checks for internal methods, such as service health check methods.

Returns:

  • (::Boolean)

    If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available. This flag is used by Google Cloud Endpoints to bypass checks for internal methods, such as service health check methods.



76
77
78
79
# File 'proto_docs/google/api/usage.rb', line 76

class UsageRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end